@@ -10,22 +10,32 @@ from abc import ABC, abstractmethod
 from typing import TYPE_CHECKING, Any, ClassVar, Literal
 
 import mcp.types as types
+from pydantic import BaseModel, ConfigDict
 
 from hud.agents.utils import log_agent_metadata_to_status, log_task_config_to_current_trace
-from hud.types import AgentResponse, MCPToolCall, MCPToolResult, Trace
+from hud.clients.base import AgentMCPClient
+from hud.types import AgentResponse, BaseAgentConfig, MCPToolCall, MCPToolResult, Trace
 from hud.utils.hud_console import HUDConsole
 from hud.utils.mcp import MCPConfigPatch, patch_mcp_config, setup_hud_telemetry
 
 if TYPE_CHECKING:
-    from hud.clients.base import AgentMCPClient
     from hud.datasets import Task
 
-    from .misc import ResponseAgent
-
 
 logger = logging.getLogger(__name__)
 
 
+class BaseCreateParams(BaseModel):
+    """Runtime parameters for agent creation."""
+
+    model_config = ConfigDict(arbitrary_types_allowed=True)
+
+    mcp_client: AgentMCPClient | None = None
+    auto_trace: bool = True
+    auto_respond: bool = False
+    verbose: bool = False
+
+
 class MCPAgent(ABC):
     """
     Base class for MCP-enabled agents.
@@ -45,80 +55,67 @@ class MCPAgent(ABC):
     `format_blocks`, and `format_tool_results`.
     """
 
-    metadata: dict[str, Any] | None = None
+    metadata: ClassVar[dict[str, Any] | None] = None
     required_tools: ClassVar[list[str]] = []  # Tools that must be available
+    config_cls: ClassVar[type[BaseAgentConfig]] = BaseAgentConfig
 
-    def __init__(
-        self,
-        mcp_client: AgentMCPClient | None = None,
-        # Filtering
-        allowed_tools: list[str] | None = None,
-        disallowed_tools: list[str] | None = None,
-        response_tool_name: str | None = None,
-        # Messages
-        system_prompt: str | None = None,
-        append_setup_output: bool = True,
-        initial_screenshot: bool = True,
-        # Misc
-        model_name: str = "mcp-agent",
-        checkpoint_name: str | None = None,
-        response_agent: ResponseAgent | None = None,
-        auto_trace: bool = True,
-        verbose: bool = False,
-    ) -> None:
-        """
-        Initialize the base MCP agent.
+    def __init__(self, params: BaseCreateParams | None = None, **kwargs: Any) -> None:
+        if params is None:
+            import warnings
 
-        Args:
-            mcp_client: Client for connecting to MCP servers. If None, a client
-                is auto-created at runtime when `run()` is called with a `Task`
-                that provides `mcp_config`.
-            allowed_tools: Names of tools to allow (None means allow all).
-            disallowed_tools: Names of tools to always exclude.
-            response_tool_name: Name of the tool to use for response.
-            system_prompt: System prompt to seed the conversation.
-            append_setup_output: Whether to append setup tool output to the
-                first turn's messages.
-            initial_screenshot: Whether to include an initial screenshot before
-                the first prompt (when supported by the environment).
-            model_name: Label used in telemetry/logging to identify the model.
-            response_agent: Optional automation that can respond to the model's
-                outputs to keep the loop going (e.g., auto-continue/stop).
-            auto_trace: If True, automatically creates a trace/span for runs.
-            verbose: If True, increases logging verbosity for developer UX.
-        """
+            warnings.warn(
+                f"Passing kwargs to {self.__class__.__name__}() is deprecated. "
+                f"Use {self.__class__.__name__}.create(...) instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            CreateParams = type(
+                f"{self.config_cls.__name__}CreateParams",
+                (BaseCreateParams, self.config_cls),
+                {"__module__": self.config_cls.__module__},
+            )
+            params = CreateParams(**kwargs)
 
-        self.mcp_client = mcp_client
-        self._auto_created_client = False  # Track if we created the client
+        config_kwargs = {
+            k: getattr(params, k) for k in self.config_cls.model_fields if hasattr(params, k)
+        }
+        self.config = self.config_cls(**config_kwargs)
+
+        self.mcp_client = params.mcp_client
+        self.model_name: str = getattr(params, "model_name", "MCPAgent")
+        self.checkpoint_name: str = getattr(params, "checkpoint_name", "unknown")
+        self.auto_respond = params.auto_respond
 
-        self.model_name = model_name
-        self.checkpoint_name = checkpoint_name
         self.console = HUDConsole(logger=logger)
 
-        # Set verbose mode if requested
-        if verbose:
+        if params.verbose:
             self.console.set_verbose(True)
 
-        # User filtering
-        self.allowed_tools: list[str] | None = allowed_tools
-        self.disallowed_tools: list[str] | None = disallowed_tools
+        self.allowed_tools = self.config.allowed_tools
+        self.disallowed_tools = self.config.disallowed_tools
+        self.system_prompt = self.config.system_prompt
+        self.append_setup_output = self.config.append_setup_output
+        self.initial_screenshot = self.config.initial_screenshot
+        self.response_tool_name = self.config.response_tool_name
+
         self._available_tools: list[types.Tool] | None = None
-
-        # Messages
-        self.system_prompt = system_prompt
-        self.append_setup_output = append_setup_output
-        self.initial_screenshot = initial_screenshot
-
-        # Initialize these here so methods can be called before initialize()
-        self._tool_map: dict[str, types.Tool] = {}  # Simplified: just name to tool
-        self.response_tool_name = response_tool_name
+        self._tool_map: dict[str, types.Tool] = {}
 
         # Trace
-        self._auto_trace = auto_trace
-        self._auto_trace_cm: Any | None = None  # Store auto-created trace context manager
+        self._auto_trace = params.auto_trace
+        self._auto_trace_cm: Any | None = None
 
-        # Response agent to automatically interact with the model
-        self.response_agent = response_agent
+    @classmethod
+    def create(cls, **kwargs: Any) -> MCPAgent:
+        """
+        Factory method to create an agent with typed parameters.
+        """
+        CreateParams = type(
+            f"{cls.config_cls.__name__}CreateParams",
+            (BaseCreateParams, cls.config_cls),
+            {"__module__": cls.config_cls.__module__},
+        )
+        return cls(params=CreateParams(**kwargs))
 
     async def initialize(self, task: str | Task | None = None) -> None:
         """Initialize the agent with task-specific configuration."""
@@ -129,7 +126,6 @@ class MCPAgent(ABC):
             from hud.clients import MCPClient
 
             self.mcp_client = MCPClient(mcp_config=task.mcp_config)
-            self._auto_created_client = True
             self.console.debug("Auto-created MCPClient from task.mcp_config")
 
         # Ensure we have a client
@@ -148,41 +144,41 @@ class MCPAgent(ABC):
         try:
             await self.mcp_client.initialize()
         except Exception as e:
+            self.console.error_log(f"Failed to initialize MCP client: {e}")
             self._handle_connection_error(e)
 
         # If task is provided, apply agent_config and add lifecycle tools
         if isinstance(task, Task) and task.agent_config:
-            if task.agent_config.get("system_prompt"):
+            agent_cfg = task.agent_config
+            if agent_cfg.system_prompt:
                 if self.system_prompt is None:
-                    self.system_prompt = task.agent_config["system_prompt"]
+                    self.system_prompt = agent_cfg.system_prompt
                 else:
-                    self.system_prompt += "\n\n" + task.agent_config["system_prompt"]
-            if "append_setup_output" in task.agent_config:
-                self.append_setup_output = task.agent_config["append_setup_output"]
-            if "initial_screenshot" in task.agent_config:
-                self.initial_screenshot = task.agent_config["initial_screenshot"]
-            if "allowed_tools" in task.agent_config:
+                    self.system_prompt += "\n\n" + agent_cfg.system_prompt
+            if "append_setup_output" in agent_cfg.model_fields_set:
+                self.append_setup_output = agent_cfg.append_setup_output
+            if "initial_screenshot" in agent_cfg.model_fields_set:
+                self.initial_screenshot = agent_cfg.initial_screenshot
+            if agent_cfg.allowed_tools is not None:
                 # If allowed_tools has already been set, we take the intersection of the two
                 # If the list had been empty, we were allowing all tools, so we overwrite this
                 if isinstance(self.allowed_tools, list) and len(self.allowed_tools) > 0:
                     # If task allows "*", keep CLI's allowed_tools unchanged
-                    if "*" not in task.agent_config["allowed_tools"]:
+                    if "*" not in agent_cfg.allowed_tools:
                         self.allowed_tools = [
-                            tool
-                            for tool in self.allowed_tools
-                            if tool in task.agent_config["allowed_tools"]
+                            tool for tool in self.allowed_tools if tool in agent_cfg.allowed_tools
                         ]
                     # else: task allows all tools, so CLI's allowed_tools takes precedence
                 else:  # If allowed_tools is None, we overwrite it
-                    self.allowed_tools = task.agent_config["allowed_tools"]
-            if "disallowed_tools" in task.agent_config:
+                    self.allowed_tools = agent_cfg.allowed_tools
+            if agent_cfg.disallowed_tools is not None:
                 # If disallowed_tools has already been set, we take the union of the two
                 if isinstance(self.disallowed_tools, list):
-                    self.disallowed_tools.extend(task.agent_config["disallowed_tools"])
+                    self.disallowed_tools.extend(agent_cfg.disallowed_tools)
                 else:  # If disallowed_tools is None, we overwrite it
-                    self.disallowed_tools = task.agent_config["disallowed_tools"]
-            if "response_tool_name" in task.agent_config:
-                self.response_tool_name = task.agent_config["response_tool_name"]
+                    self.disallowed_tools = agent_cfg.disallowed_tools
+            if agent_cfg.response_tool_name is not None:
+                self.response_tool_name = agent_cfg.response_tool_name
 
         all_tools = await self.mcp_client.list_tools()
         self._available_tools = []
@@ -201,6 +197,15 @@ class MCPAgent(ABC):
                 continue
             self._available_tools.append(tool)
 
+        # Validate required tools are present
+        available_tool_names = {t.name for t in self._available_tools}
+        missing_tools = [tool for tool in self.required_tools if tool not in available_tool_names]
+        if missing_tools:
+            raise ValueError(
+                f"Required tools are missing: {missing_tools}. "
+                f"Available tools: {sorted(available_tool_names)}"
+            )
+
         self.console.info(
             f"Agent initialized with {len(self.get_available_tools())} tools: {', '.join([t.name for t in self.get_available_tools()])}"  # noqa: E501
         )
@@ -290,6 +295,10 @@ class MCPAgent(ABC):
                 self.console.progress_log(f"Setting up tool phase: {task.setup_tool}")
                 results = await self.call_tools(task.setup_tool)
                 if any(result.isError for result in results):
+                    for result in results:
+                        if result.isError:
+                            self.console.error_log(f"Error in setup tool: {result}")
+
                     return Trace(
                         reward=0.0,
                         done=True,
@@ -389,6 +398,8 @@ class MCPAgent(ABC):
         final_response = None
         error = None
 
+        messages: list[Any] = []
+
         try:
             # Start with system messages
             messages = await self.get_system_messages()
@@ -413,15 +424,16 @@ class MCPAgent(ABC):
 
                     # Check if we should stop
                     if response.done or not response.tool_calls:
-                        # Optional external ResponseAgent to decide whether to stop
-                        decision = "STOP"
-                        if self.response_agent is not None and response.content:
+                        # Use auto_respond to decide whether to stop
+                        decision: Literal["STOP", "CONTINUE"] = "STOP"
+                        if self.auto_respond and response.content:
                             try:
-                                decision = await self.response_agent.determine_response(
-                                    response.content
-                                )
+                                from hud.agents.misc import ResponseAgent
+
+                                response_agent = ResponseAgent()
+                                decision = await response_agent.determine_response(response.content)
                             except Exception as e:
-                                self.console.warning_log(f"ResponseAgent failed: {e}")
+                                self.console.warning_log(f"Auto-respond failed: {e}")
                         if decision == "STOP":
                             # Try to submit response through lifecycle tool
                             await self._maybe_submit_response(response, messages)
@@ -436,11 +448,7 @@ class MCPAgent(ABC):
 
                     # 2. Execute tools
                     tool_calls = response.tool_calls
-                    for tool_call in tool_calls:
-                        self.console.info_log(f"{tool_call}")
                     tool_results = await self.call_tools(tool_calls)
-                    for tool_result in tool_results:
-                        self.console.info_log(f"{tool_result}")
 
                     # 3. Format tool results and add to messages
                     tool_messages = await self.format_tool_results(tool_calls, tool_results)
@@ -699,8 +707,8 @@ class MCPAgent(ABC):
             finally:
                 self._auto_trace_cm = None
 
-        # Clean up auto-created client
-        if self._auto_created_client and self.mcp_client:
+        # Always clean up the client
+        if self.mcp_client:
             try:
                 await self.mcp_client.shutdown()
                 self.console.debug("Closed auto-created MCPClient")
@@ -708,7 +716,6 @@ class MCPAgent(ABC):
                 self.console.warning_log(f"Failed to close auto-created client: {e}")
             finally:
                 self.mcp_client = None
-                self._auto_created_client = False
 
     def _is_connection_error(self, e: Exception) -> bool:
         """Check if an exception is a connection error."""
