@@ -2,150 +2,16 @@
 
 from __future__ import annotations
 
-from unittest.mock import AsyncMock, MagicMock, Mock, patch
+from types import SimpleNamespace
+from typing import Any
+from unittest.mock import AsyncMock, MagicMock, patch
 
 import pytest
+from anthropic import AsyncAnthropic
 from mcp import types
 
-from hud.cli.eval import (
-    build_agent,
-    run_single_task,
-)
-from hud.types import AgentType, Task, Trace
-
-
-class TestBuildAgent:
-    """Test the build_agent function."""
-
-    def test_builds_integration_test_agent(self) -> None:
-        """
-        Test building an integration test agent.
-        """
-        with patch("hud.agents.misc.integration_test_agent.IntegrationTestRunner") as mock_runner:
-            mock_instance = Mock()
-            mock_runner.return_value = mock_instance
-
-            # Test with verbose=False
-            result = build_agent(AgentType.INTEGRATION_TEST, verbose=False)
-
-            mock_runner.assert_called_once_with(verbose=False)
-            assert result == mock_instance
-
-    def test_builds_claude_agent(self) -> None:
-        """
-        Test building a Claude agent with default model.
-        """
-        with patch("hud.agents.ClaudeAgent") as mock_runner:
-            mock_instance = Mock()
-            mock_runner.return_value = mock_instance
-
-            # Test with verbose=False
-            result = build_agent(AgentType.CLAUDE, verbose=False)
-
-            mock_runner.assert_called_once_with(model="claude-sonnet-4-5", verbose=False)
-            assert result == mock_instance
-
-    def test_builds_claude_agent_with_custom_model_and_allowed_tools(self) -> None:
-        """
-        Test building a Claude agent with custom model name and allowed tools.
-        """
-        with patch("hud.agents.ClaudeAgent") as mock_runner:
-            mock_instance = Mock()
-            mock_runner.return_value = mock_instance
-
-            # Test with verbose=False
-            result = build_agent(
-                AgentType.CLAUDE,
-                model="claude-sonnet-4-5",
-                allowed_tools=["act"],
-                verbose=True,
-            )
-
-            mock_runner.assert_called_once_with(
-                model="claude-sonnet-4-5",
-                allowed_tools=["act"],
-                verbose=True,
-            )
-            assert result == mock_instance
-
-    def test_builds_gemini_agent(self) -> None:
-        """Test building a Gemini agent."""
-        with patch("hud.agents.GeminiAgent") as mock_runner:
-            mock_instance = Mock()
-            mock_runner.return_value = mock_instance
-
-            result = build_agent(
-                AgentType.GEMINI,
-                model="gemini-test",
-                allowed_tools=["gemini_computer"],
-                verbose=True,
-            )
-
-            mock_runner.assert_called_once_with(
-                model="gemini-test",
-                verbose=True,
-                allowed_tools=["gemini_computer"],
-            )
-            assert result == mock_instance
-
-
-class TestRunSingleTask:
-    """Test the run_single_task function."""
-
-    @pytest.mark.asyncio
-    async def test_applies_agent_config_from_task(self) -> None:
-        """Test that task.agent_config is applied during agent initialization."""
-        mock_task = Task(
-            prompt="Test",
-            mcp_config={"local": {"url": "http://localhost:8765/mcp"}},
-            agent_config={
-                "system_prompt": "Custom instructions",
-                "allowed_tools": ["tool1", "tool2"],
-                "append_setup_output": False,
-            },
-        )
-        mock_agent = AsyncMock(
-            initialize=AsyncMock(), run=AsyncMock(return_value=Trace(reward=1.0, done=True))
-        )
-
-        with (
-            patch("hud.utils.tasks.load_tasks", return_value=[mock_task]),
-            patch(
-                "hud.agents.misc.integration_test_agent.IntegrationTestRunner",
-                return_value=mock_agent,
-            ),
-            patch("hud.cli.eval.find_environment_dir", return_value=None),
-            patch("hud.cli.eval.hud.trace"),
-        ):
-            await run_single_task("test.json", agent_type=AgentType.INTEGRATION_TEST, max_steps=10)
-
-            # Verify agent.run was called with the task containing agent_config
-            mock_agent.run.assert_called_once()
-            called_task = mock_agent.run.call_args[0][0]
-            assert called_task.agent_config == mock_task.agent_config
-
-    @pytest.mark.asyncio
-    async def test_runs_with_group_size_greater_than_one(self) -> None:
-        """Test that group_size > 1 triggers run_tasks_grouped instead of agent.run."""
-        mock_task = Task(prompt="Test", mcp_config={"local": {"url": "http://localhost:8765/mcp"}})
-
-        with (
-            patch("hud.utils.tasks.load_tasks", return_value=[mock_task]),
-            patch("hud.cli.eval.run_tasks_grouped", new_callable=AsyncMock) as mock_grouped,
-            patch("hud.cli.eval.display_group_statistics"),
-            patch("hud.cli.eval.find_environment_dir", return_value=None),
-            patch("hud.cli.eval.hud.trace"),
-        ):
-            mock_grouped.return_value = [{"task": mock_task, "rewards": [1.0, 0.5]}]
-
-            await run_single_task(
-                "test.json", agent_type=AgentType.INTEGRATION_TEST, group_size=3, max_steps=10
-            )
-
-            # Verify run_tasks_grouped was called with correct group_size
-            mock_grouped.assert_called_once()
-            assert mock_grouped.call_args.kwargs["group_size"] == 3
-            assert mock_grouped.call_args.kwargs["max_steps"] == 10
+from hud.agents.tests.conftest import MockMCPClient
+from hud.types import Task, Trace
 
 
 class TestToolFiltering:
@@ -154,38 +20,38 @@ class TestToolFiltering:
     @pytest.fixture
     def mock_mcp_client(self):
         """Fixture for mock MCP client."""
-        client = MagicMock()
-        client.initialize = AsyncMock()
-        client.mcp_config = {"local": {"url": "http://localhost"}}
-        return client
+        return MockMCPClient()
 
     @pytest.fixture
     def mock_model_client(self):
-        """Fixture for mock Anthropic client."""
-        return MagicMock()
+        """Fixture for a lightweight Anthropic client."""
+        client = AsyncAnthropic(api_key="test_key")
+        client.__dict__["beta"] = SimpleNamespace(messages=AsyncMock())
+        return client
 
     async def _run_agent_with_tools(
         self,
         mock_mcp_client: MagicMock,
         mock_model_client: MagicMock,
         tools: list[types.Tool],
-        agent_config: dict | None = None,
+        agent_config: dict[str, Any] | None = None,
     ) -> list[types.Tool]:
         """Helper to create agent, initialize with tools and config, return filtered tools."""
         from hud.agents import ClaudeAgent
+        from hud.types import BaseAgentConfig
 
         mock_mcp_client.list_tools = AsyncMock(return_value=tools)
 
         task = Task(
             prompt="Test",
             mcp_config={"local": {"url": "http://localhost"}},
-            agent_config=agent_config or {},
+            agent_config=BaseAgentConfig(**agent_config) if agent_config else None,
         )
 
-        agent = ClaudeAgent(
+        agent = ClaudeAgent.create(
             mcp_client=mock_mcp_client,
             model_client=mock_model_client,
-            model="test",
+            checkpoint_name="test",
             validate_api_key=False,
         )
         await agent.initialize(task)
@@ -531,12 +397,7 @@ class TestSystemPromptHandling:
     @pytest.fixture
     def mock_mcp_client(self):
         """Fixture for mock MCP client."""
-        client = MagicMock()
-        client.initialize = AsyncMock()
-        client.list_tools = AsyncMock(return_value=[])
-        client.shutdown = AsyncMock()
-        client.mcp_config = {"local": {"url": "http://localhost:8765/mcp"}}
-        return client
+        return MockMCPClient()
 
     @pytest.fixture
     def captured_agent_fixture(self):
