@@ -6,7 +6,7 @@ import json
 from typing import Any
 
 import questionary
-from mcp.types import TextContent
+from mcp.types import ImageContent, TextContent
 from rich.console import Console
 from rich.panel import Panel
 from rich.prompt import Prompt
@@ -39,7 +39,8 @@ class InteractiveMCPTester:
         """Connect to the MCP server."""
         try:
             # Create MCP config for HTTP transport
-            config = {"server": {"url": self.server_url}}
+            # Note: We explicitly set auth to None to prevent OAuth discovery attempts
+            config = {"server": {"url": self.server_url, "auth": None}}
 
             self.client = MCPClient(
                 mcp_config=config,
@@ -241,7 +242,27 @@ class InteractiveMCPTester:
             # Prompt for each property
             args = {}
             for prop_name, prop_schema in properties.items():
-                prop_type = prop_schema.get("type", "string")
+                prop_type = prop_schema.get("type")
+                if not prop_type and "anyOf" in prop_schema:
+                    prop_type = next(
+                        (
+                            s.get("type")
+                            for s in prop_schema.get("anyOf", [])
+                            if s.get("type") != "null"
+                        ),
+                        None,
+                    )
+                if not prop_type and "oneOf" in prop_schema:
+                    prop_type = next(
+                        (
+                            s.get("type")
+                            for s in prop_schema.get("oneOf", [])
+                            if s.get("type") != "null"
+                        ),
+                        None,
+                    )
+                prop_type = prop_type or "string"
+
                 description = prop_schema.get("description", "")
                 is_required = prop_name in required
 
@@ -352,6 +373,16 @@ class InteractiveMCPTester:
                             border_style="green" if not result.isError else "red",
                         )
                     )
+                elif isinstance(content, ImageContent):
+                    mime_type = getattr(content, "mimeType", "image/png")
+                    data_length = len(content.data) if hasattr(content, "data") else 0
+                    console.print(
+                        Panel(
+                            f"📷 Image ({mime_type})\nSize: {data_length:,} bytes (base64 encoded)",
+                            title="Result",
+                            border_style="green" if not result.isError else "red",
+                        )
+                    )
                 else:
                     # Handle other content types
                     console.print(json.dumps(content, indent=2))
