@@ -17,15 +17,23 @@ class MCPConfigPatch(BaseModel):
     meta: dict[str, Any] | None = Field(default_factory=dict, alias="meta")
 
 
+def _is_hud_server(url: str) -> bool:
+    """Check if a URL is a HUD MCP server.
+
+    Matches any mcp.hud.* domain (including .ai, .so, and future domains).
+    """
+    if not url:
+        return False
+    return "mcp.hud." in url.lower()
+
+
 def patch_mcp_config(mcp_config: dict[str, dict[str, Any]], patch: MCPConfigPatch) -> None:
     """Patch MCP config with additional values."""
-    hud_mcp_url = settings.hud_mcp_url
-
     for server_cfg in mcp_config.values():
         url = server_cfg.get("url", "")
 
         # 1) HTTP header lane (only for hud MCP servers)
-        if hud_mcp_url in url and patch.headers:
+        if _is_hud_server(url) and patch.headers:
             for key, value in patch.headers.items():
                 headers = server_cfg.setdefault("headers", {})
                 headers.setdefault(key, value)
@@ -46,13 +54,12 @@ def setup_hud_telemetry(
         The auto-created trace context manager if one was created, None otherwise.
         Caller is responsible for exiting the context manager.
     """
-    if not mcp_config:
+    if mcp_config is None:
         raise ValueError("Please run initialize() before setting up client-side telemetry")
 
     # Check if there are any HUD servers to setup telemetry for
-    hud_mcp_url = settings.hud_mcp_url
     has_hud_servers = any(
-        hud_mcp_url in server_cfg.get("url", "") for server_cfg in mcp_config.values()
+        _is_hud_server(server_cfg.get("url", "")) for server_cfg in mcp_config.values()
     )
 
     # If no HUD servers, no need for telemetry setup
@@ -66,8 +73,13 @@ def setup_hud_telemetry(
     auto_trace_cm = None
 
     if not run_id and auto_trace:
+        # Start an auto trace and capture its ID for headers/metadata
         auto_trace_cm = trace("My Trace")
-        run_id = auto_trace_cm.__enter__()
+        _trace_obj = auto_trace_cm.__enter__()
+        try:
+            run_id = getattr(_trace_obj, "id", None) or str(_trace_obj)
+        except Exception:  # pragma: no cover - fallback shouldn't fail lint
+            run_id = None
 
     # Patch HUD servers with run-id (works whether auto or user trace)
     if run_id:
